/************************************************************/
/*  This code using dynamic memory managment for DCPLBs.    */
/*                                                          */
/*  The Exception Handler for the CPLB miss searches for    */
/*  required CPLB entry in the CPLB page table. This value  */
/*  then replaces one of the old CPLB entries. Round robing */
/*  scheduling is used for CPLB replacement                 */
/*                                                          */
/*                              Initial Version             */
/*                              Kunal Singh                 */
/*                              DSP applications, ADI       */
/*                              Dated 3 April, 2005         */
/*                                                          */
/*                              Re-Release                  */
/*                              for VisualDSP++ 5.0         */
/*                              Andreas Pellkofer           */
/*                              GPDSP Applications, ADI     */
/*                              Dated 9 March, 2009         */
/*                                                          */
/************************************************************/


#include <blackfin.h>
#include <services_types.h>
#include <stdio.h>
#include <sys/exception.h>
#include "main.h"


/********************************************/
/*                                          */
/*      Exception Handler                   */
/*                                          */
/********************************************/
EX_EXCEPTION_HANDLER(exception_isr);


/************************************************/
/*                                              */
/*      Entries for the DCPLBx_ADDR             */
/*                                              */
/************************************************/
#pragma section ("data1")

u32 D_cplb_addrs[] =
    {
        0xff800000, // L1 DATAA. 16Kbytes (1Mbytes prog)
        0xff900000, // L1 DATAB, 16Kbytes (1Mbytes prog)
        0x00000000, // SDRAM0, 1Mbytes
        0x00100000, // SDRAM0, 1Mbytes
        0x00200000, // SDRAM0, 1Mbytes
        0x00300000, // SDRAM0, 1Mbytes
        0x00400000, // SDRAM0, 1Mbytes
        0x00500000, // SDRAM0, 1Mbytes
        0x00600000, // SDRAM0, 1Mbytes
        0x00700000, // SDRAM0, 1Mbytes
        0x00800000, // SDRAM1, 1Mbytes
        0x00900000, // SDRAM1, 1Mbytes
        0x00A00000, // SDRAM1, 1Mbytes
        0x00B00000, // SDRAM1, 1Mbytes
        0x00C00000, // SDRAM1, 1Mbytes
        0x00D00000, // SDRAM1, 1Mbytes
        0x00E00000, // SDRAM1, 1Mbytes
        0x00F00000, // SDRAM1, 1Mbytes
        0x01000000, // SDRAM2, 1Mbytes
        0x01100000, // SDRAM2, 1Mbytes
        0x01200000, // SDRAM2, 1Mbytes
        0x01300000, // SDRAM2, 1Mbytes
        0x01400000, // SDRAM2, 1Mbytes
        0x01500000, // SDRAM2, 1Mbytes
        0x01600000, // SDRAM2, 1Mbytes
        0x01700000, // SDRAM2, 1Mbytes
        0x01800000, // SDRAM3, 1Mbytes
        0x01900000, // SDRAM3, 1Mbytes
        0x01A00000, // SDRAM3, 1Mbytes
        0x01B00000, // SDRAM3, 1Mbytes
        0x01C00000, // SDRAM3, 1Mbytes
        0x01D00000, // SDRAM3, 1Mbytes
        0x01E00000, // SDRAM3, 1Mbytes
        0x01F00000
    };

/************************************************/
/*                                              */
/*      Entries for the DCPLBx_DATA             */
/*                                              */
/************************************************/
#pragma section ("data1")

u32 D_cplb_data[] =
    {
        0x2001f,
        0x2001f,
        0x2D01d,
        0x2D01d,
        0x2D01d,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f,
        0x2D01f
    };

/************************************************/
/*                                              */
/*      Entries for the ICPLBx_ADDR             */
/*                                              */
/************************************************/
#pragma section ("data1")

u32 I_cplb_addrs[] =
    {
        0xFFA00000,
        0x00000000,
        0x00400000,
        0x00800000,
        0x00C00000,
        0x01000000,
        0x01400000,
        0x01800000,
        0x01C00000
    };

/************************************************/
/*                                              */
/*      Entries for the ICPLBx_DATA             */
/*                                              */
/************************************************/
#pragma section ("data1")

u32 I_cplb_data[] =
    {
        0x00020003,
        0x00031005,
        0x00031005,
        0x00031005,
        0x00031005,
        0x00031005,
        0x00031005,
        0x00031005,
        0x00031005
    };

/********************************/
/*                              */
/*  ICache -    1: Lock the way */
/*              0: Don't Lock   */
/*                              */
/********************************/
#pragma section ("data1")

u32 Lock_Control[4] =
    {
        0,
        0,
        0,
        0
    };


#pragma section("sdram1")
u32 data_A [ARRAY_LENGTH];


#pragma section("sdram2")
u32 data_B [ARRAY_LENGTH];


#pragma section("sdram3")
u32 Result [ARRAY_LENGTH];


volatile u32 decLow, decHigh;



void main()
{
    u32 i;
    u32 dcplb_cnt, icplb_cnt, d_bank_cnt, disable_lru;

    register_handler(ik_exception, exception_isr);
    asm ("ssync;") ;



    /****************************/
    /*  Configure the DCPLBs    */
    /*  Enable D_CACHE          */
    /*  Both the Banks as cache */
    /****************************/
    dcplb_cnt = DCPLB_CNT;
    d_bank_cnt = 2;
    Config_D_Cache(D_cplb_addrs, D_cplb_data, dcplb_cnt, d_bank_cnt);

    /****************************/
    /*  Configure the ICPLBs    */
    /*  Enable I_CACHE          */
    /*  All ways Enabled        */
    /*  Use Modified LRU Policy */
    /****************************/
    for (i=0; i<4; i++)
    Lock_Control[i] = 0;
    disable_lru = 0;
    icplb_cnt = ICPLB_CNT;
    Config_I_Cache(I_cplb_addrs, I_cplb_data, icplb_cnt, disable_lru, Lock_Control);

    /************************************/
    /* Initialize the data arrays       */
    /* A DCPLB miss is generated here   */
    /* The Exception Handler is called  */
    /************************************/
    for (i = 0; i<ARRAY_LENGTH; i++)
    {
        data_A[i] = i;
        data_B[i] = i;
    }

    /* Call to function */
    matrix_add(Result, data_A, data_B, ARRAY_LENGTH);

    printf("done ...\n");
}
