/************************************************************************
*                                                                       *
* nBlackfin.h                                                           *
*                                                                       *
* (c) Copyright 2007-2008 Analog Devices, Inc.  All rights reserved.    *
*                                                                       *
************************************************************************/


/* *********************  PLL MASKS  ************************ */
/* PLL_CTL Masks */
#define nDF                     0x0         /* 0: PLL = CLKIN, 1: PLL = CLKIN/2 */
#define nPLL_CLKIN_DIV2         nDF         /* Pass CLKIN/2 to PLL */
#define nPLL_OFF                0x0         /* Shut off PLL clocks */
#define nSTOPCK_OFF             0x0         /* Core clock off */
#define nSTOPCK                 0x0         /* Core Clock Off */
#define nPDWN                   0x0         /* Put the PLL in a Deep Sleep state */

#define nIN_DELAY               0x0         /* EBIU Input Delay Select */
#define nOUT_DELAY              0x0         /* EBIU Output Delay Select */
#define nBYPASS                 0x0         /* Bypass the PLL */


/* PLL_STAT Masks */
#define nVSTAT                  0x0         /* Voltage Regulator Status: Regulator not at programmed voltage */
#define nCORE_IDLE              0x0         /* processor is in the IDLE operating mode */
#define nPLL_LOCKED             0x0         /* PLL_LOCKCNT Has Been Reached */
#define nSLEEP                  0x0         /* processor is in the Sleep operating mode */
#define nDEEP_SLEEP             0x0         /* processor is in the Deep Sleep operating mode */
#define nACTIVE_PLLENABLED      0x0         /* Processor In Active Mode With PLL Enabled */
#define nFULL_ON                0x0         /* Processor In Full On Mode */
#define nACTIVE_PLLDISABLED     0x0         /* Processor In Active Mode With PLL Disabled */


/* VR_CTL Masks */
#define nFREQ                   0x0         /* Switching Oscillator Frequency For Regulator */
#define nHIBERNATE              0x0         /* Powerdown/Bypass On-Board Regulation */
#define nSCKELOW                0x0         /* Do Not Drive SCKE High During Reset After Hibernate */
#define nWAKE                   0x0         /* Enable RTC/Reset Wakeup From Hibernate */
#define nPHYWE                  0x0         /* Enable PHY Wakeup From Hibernate */
#define nCANWE                  0x0         /* Enable CAN Wakeup From Hibernate */
#define nGPWE                   0x0         /* Enable General-Purpose Wakeup From Hibernate */
#define nUSBWE                  0x0         /* Enable USB Wakeup From Hibernate */
#define nVTRIM                  0x0         /* VTRIM [3:0]: Not yet documented */


/* *********************  ASYNCHRONOUS MEMORY CONTROLLER MASKS  ************* */
/* EBIU_AMGCTL Masks */
#define nAMCKEN                 0x0         /* Enable CLKOUT */
#define nCDPRIO                 0x0         /* Core has priority over DMA for external accesses */


/* **********************  SDRAM CONTROLLER MASKS  *************************** */
//#ifndef nEBE
/* EBIU_SDBCTL Masks */
#define nEBE                    0x0         /* Enable SDRAM external bank */
#define nEBSZ_32                0x0         /* SDRAM External Bank Size = 32MB */
#define nEBSZ_64                0x0         /* SDRAM External Bank Size = 64MB */

/* EBIU_SDGCTL Masks */
#define nSCTLE                  0x0         /* Enable SCLK[0], /SRAS, /SCAS, /SWE, SDQM[3:0] */
#define nCL_2                   0x0         /* SDRAM CAS latency = 2 cycles */
#define nCL_3                   0x0         /* SDRAM CAS latency = 3 cycles */
#define nPFE                    0x0         /* Enable SDRAM prefetch */
#define nPFP                    0x0         /* Prefetch has priority over AMC requests */
#define nPUPSD                  0x0         /* Power-up start delay */
#define nPSM                    0x0         /* SDRAM power-up sequence = Precharge, mode register set, 8 CBR refresh cycles */
#define nPSS                    0x0         /* enable SDRAM power-up sequence on next SDRAM access */
#define nSRFS                   0x0         /* Start SDRAM self-refresh mode */
#define nEBUFE                  0x0         /* Enable external buffering timing */
#define nFBBRW                  0x0         /* Fast back-to-back read write enable */
#define nEMREN                  0x0         /* Extended mode register enable */
#define nTCSR                   0x0         /* Temp compensated self refresh value 85 deg C */
#define nCDDBG                  0x0         /* Tristate SDRAM controls during bus grant */


/* ************** REAL TIME CLOCK (RTC) MACROS *************************/
/* Bit masks for RTC_ISTAT / RTC_ICTL */
#define nSTOPWATCH      0x0 /* Stopwatch Interrupt Enable */
#define nALARM          0x0 /* Alarm Interrupt Enable */
#define nSECOND         0x0 /* Seconds (1 Hz) Interrupt Enable */
#define nMINUTE         0x0 /* Minutes Interrupt Enable */
#define nHOUR           0x0 /* Hours Interrupt Enable */
#define nDAY            0x0 /* 24 Hours (Days) Interrupt Enable */
#define nDAY_ALARM      0x0 /* Day Alarm (Day, Hour, Minute, Second) Interrupt Enable */
#define nWRITE_PENDING  0x0 /* Write Pending Status */
#define nWRITE_COMPLETE 0x0 /* Write Complete Interrupt Enable */



/* ***********  SERIAL PERIPHERAL INTERFACE (SPI) MASKS  ****************************/
/* SPI_STAT Masks */
#define nSPIF                   0x0         /* SPI Finished (Single-Word Transfer Complete) */
#define nMODF                   0x0         /* Mode Fault Error (Another Device Tried To Become Master) */
#define nTXE                    0x0         /* Transmission Error (Data Sent With No New Data In TDBR) */
#define nTXS                    0x0         /* SPI_TDBR Data Buffer Status (Full/Empty*) */
#define nRBSY                   0x0         /* Receive Error (Data Received With RDBR Full) */
#define nRXS                    0x0         /* SPI_RDBR Data Buffer Status (Full/Empty*) */
#define nTXCOL                  0x0         /* Transmit Collision Error (Corrupt Data May Have Been Sent) */


/* *******************  SERIAL PORT MASKS  **************************************/
/* SPORTx_TCR1 Masks */
#define nTSPEN                  0x0         /* Transmit Enable */
#define nITCLK                  0x0         /* Internal Transmit Clock Select */
#define nTLSBIT                 0x0         /* Transmit Bit Order */
#define nITFS                   0x0         /* Internal Transmit Frame Sync Select */
#define nTFSR                   0x0         /* Transmit Frame Sync Required Select */
#define nDITFS                  0x0         /* Data-Independent Transmit Frame Sync Select */
#define nLTFS                   0x0         /* Low Transmit Frame Sync Select */
#define nLATFS                  0x0         /* Late Transmit Frame Sync Select */
#define nTCKFE                  0x0         /* Clock Falling Edge Select */

/* SPORTx_TCR2 Masks and Macro */
#define nTXSE                   0x0         /* TX Secondary Enable */
#define nTSFSE                  0x0         /* Transmit Stereo Frame Sync Enable */
#define nTRFST                  0x0         /* Left/Right Order (1 = Right Channel 1st) */

/* SPORTx_RCR1 Masks */
#define nRSPEN                  0x0         /* Receive Enable */
#define nIRCLK                  0x0         /* Internal Receive Clock Select */
#define nRLSBIT                 0x0         /* Receive Bit Order */
#define nIRFS                   0x0         /* Internal Receive Frame Sync Select */
#define nRFSR                   0x0         /* Receive Frame Sync Required Select */
#define nLRFS                   0x0         /* Low Receive Frame Sync Select */
#define nLARFS                  0x0         /* Late Receive Frame Sync Select */
#define nRCKFE                  0x0         /* Clock Falling Edge Select */

/* SPORTx_RCR2 Masks */
#define nRXSE                   0x0         /* RX Secondary Enable */
#define nRSFSE                  0x0         /* RX Stereo Frame Sync Enable */
#define nRRFST                  0x0         /* Right-First Data Order */

/* SPORTx_xCR1 */
#define nxSPEN                  0x0         /* SPORT enable */
#define nIxCLK                  0x0         /* Internal Clock Select */
#define nxLSBIT                 0x0         /* Transmit Bit Order */
#define nIxFS                   0x0         /* Internal Transmit Frame Sync Select */
#define nLAxFS                  0x0         /* Late Frame Sync Select */
#define nLxFS                   0x0         /* Low Frame Sync Select */
#define nDIxFS                  0x0         /* Data-Independent Frame Sync Select */
#define nxFSR                   0x0         /* Transmit Frame Sync Required Select */
#define nxCKFE                  0x0         /* Clock Falling Edge Select */

/* SPORTx_xCR2 */
#define nxRFST                  0x0         /* Left/Right Order (1 = Right Channel 1st) */
#define nxSFSE                  0x0         /* Stereo Frame Sync Enable */
#define nxXSE                   0x0         /* Secondary Enable */

/* SPORTx_STAT Masks */
#define nRXNE                   0x0         /* Receive FIFO Not Empty Status */
#define nRUVF                   0x0         /* Sticky Receive Underflow Status */
#define nROVF                   0x0         /* Sticky Receive Overflow Status */
#define nTXF                    0x0         /* Transmit FIFO Full Status */
#define nTUVF                   0x0         /* Sticky Transmit Underflow Status */
#define nTOVF                   0x0         /* Sticky Transmit Overflow Status */
#define nTXHRE                  0x0         /* Transmit Hold Register Empty */


/* **************************  DMA CONTROLLER MASKS  ********************************/
/* DMAx_CONFIG, MDMA_yy_CONFIG Masks */
#define nDI_EN                  0x0         /* Data Interrupt Enable */
#define nDI_SEL                 0x0         /* Data Interrupt Timing Select */
#define nSYNC                   0x0         /* Work Unit Transitions */
#define nDMA2D                  0x0         /* DMA Mode */
#define nWNR                    0x0         /* DMA Direction */
#define nDMAEN                  0x0         /* DMA Channel Enable */
#define nRESTART                0x0         /* Work Unit Transitions */


/****************************************************************************
 EOF
*****************************************************************************/
